package api;

import com.github.cliftonlabs.json_simple.JsonObject;
import com.github.cliftonlabs.json_simple.Jsoner;
import com.sun.net.httpserver.HttpExchange;
import com.sun.net.httpserver.HttpHandler;
import controller.ModelController;
import controller.QuestionnaireController;
import controller.SessionController;

import java.io.IOException;
import java.io.OutputStream;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;

public class ResponseHandler implements HttpHandler {

    public JsonObject getResponse(String iMethod, String [] iPath, String iBody, ModelController iController)
    {
        JsonObject vResponseObject = new JsonObject();
        JsonObject vRequestJson = new JsonObject();

        try {
            // ---------------------------------
            // parse request body : either empty or a JSON Object
            // ---------------------------------
            if (iBody.length() > 0) {
                vRequestJson = Jsoner.deserialize(iBody, vRequestJson);
            }

            // ---------------------------------
            // Decide which controller method should process the request
            // ---------------------------------
            switch (iMethod) {
                case "GET":
                    switch (iPath.length) {
                        case 0:
                            vResponseObject = iController.get(vRequestJson); break;
                        case 1:
                            vResponseObject = iController.getEntriesForId(iPath[0], vRequestJson); break;
                        default: throw new Exception(String.format("GET with %d subdirectories not implemented", iPath.length));
                    }
                    break;
                case "POST":
                    switch (iPath.length) {
                        case 1: vResponseObject = iController.createEntry(vRequestJson); break;
                        default: throw new Exception(String.format("POST with %d subdirectories not implemented", iPath.length));
                    }
                    break;
                case "PUT":
                    switch (iPath.length) {
                        case 1: vResponseObject = iController.updateEntry(iPath[0], vRequestJson); break;
                        default: throw new Exception(String.format("PUT with %d subdirectories not implemented", iPath.length));
                    }
                    break;
                case "DELETE":
                    switch (iPath.length) {
                        case 1: vResponseObject = iController.deleteEntry(iPath[0]); break;
                        default: throw new Exception(String.format("DELETE with %d subdirectories not implemented", iPath.length));
                    }break;
                default: throw new Exception(String.format("Method '%s' not implemented", iMethod));
            }
        }catch(Exception vex)
        {
            vex.printStackTrace();
            vResponseObject.put("error",vex.getMessage());
        }

        return vResponseObject;
    }

    @Override
    public void handle(HttpExchange iExchange) throws IOException {
        ModelController vController;
        byte[] vRequestAnswerBytes;
        OutputStream vOutputStream = iExchange.getResponseBody();
        String[] vRequestURI = iExchange.getRequestURI().getPath().split("/");
        String vRequestMethod = iExchange.getRequestMethod();
        String vRequestBody = new String(iExchange.getRequestBody().readAllBytes());
        iExchange.getResponseHeaders().set("Content-Type","application/json; charset=utf-8");
        iExchange.getResponseHeaders().set("Access-Control-Allow-Origin", "*");
        iExchange.getResponseHeaders().set("Access-Control-Allow-Methods", "*");
        iExchange.getResponseHeaders().set("Access-Control-Allow-Headers", "*");

        try {
            if(vRequestURI.length < 1)
                throw new Exception(String.format("Unusable path '%s'", iExchange.getRequestURI().getPath()));

            switch (vRequestURI[1]) {
                case "questionnaire":
                    vController = new QuestionnaireController();
                    break;
                case "session":
                    vController = new SessionController();
                    break;
                default:
                    throw new Exception(String.format("Unknown path '%s'", vRequestURI[1]));
            }

            vRequestAnswerBytes = getResponse(vRequestMethod, Arrays.copyOfRange(vRequestURI,2, vRequestURI.length), vRequestBody, vController).toJson().getBytes(StandardCharsets.UTF_8);
            iExchange.sendResponseHeaders(200, vRequestAnswerBytes.length);
        }
        catch(Exception vex){
            JsonObject vErrorJsonObect = new JsonObject();
            vErrorJsonObect.put("error", vex.getMessage());
            vRequestAnswerBytes = vErrorJsonObect.toJson().getBytes(StandardCharsets.UTF_8);
            vex.printStackTrace();
            iExchange.sendResponseHeaders(500, vRequestAnswerBytes.length);
            }

        vOutputStream.write(vRequestAnswerBytes);
        vOutputStream.close();
    }
}
