package model.questionnaire;

import com.github.cliftonlabs.json_simple.JsonObject;
import com.github.cliftonlabs.json_simple.Jsonable;
import model.personnality.Trait;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;
import java.util.UUID;

import static api.JsonKeys.*;

public class Answer implements Jsonable {

    private final UUID fId;
    private final float   fWeight;
    private final Trait   fTrait;
    private final String  fDescription;


    public Answer(String iDescription, Trait iTrait, float iWeight)
    {
        fId = UUID.randomUUID();    // I feel like I should check this is truly unique among answers
        fWeight         = iWeight;
        fTrait          = iTrait;
        fDescription    = iDescription;
    }

    public Trait getTrait() { return fTrait; }
    public float getWeight() { return fWeight; }
    public UUID getId() { return fId; }


    // ------------------------------------------------------------------
    // Jsonable Implementation
    // ------------------------------------------------------------------
    public JsonObject asJsonObject(){
        final JsonObject vResult = new JsonObject();
        vResult.put(KEY_DESCRIPTION, fDescription);
        vResult.put(KEY_ID, fId.toString());
        return vResult;
    }


    @Override
    public String toJson() {
        final StringWriter writable = new StringWriter();
        try{
            this.toJson(writable);
        }catch(final IOException caught)
        {
            caught.printStackTrace();
        }
        return writable.toString();
    }


    @Override
    public void toJson(Writer writable) throws IOException {

        writable.write(new String(asJsonObject().toJson().getBytes(StandardCharsets.UTF_8), StandardCharsets.UTF_8));
    }
}
