package model.questionnaire;

import com.github.cliftonlabs.json_simple.JsonObject;
import com.github.cliftonlabs.json_simple.Jsonable;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

import static api.JsonKeys.*;

public class Question implements Jsonable {

    private static final HashMap<UUID, Question> sQuestions = new HashMap<>();
    private final UUID fId;
    private final List<Answer> fAnswers;
    private final String fName;

    public Question(String iName, List<Answer> iAnswers)
    {
        fId = UUID.randomUUID();
        fName = iName;
        fAnswers = iAnswers;
        sQuestions.put(fId, this);
    }


    public static Question getForUUID(UUID iId) {
        return sQuestions.get(iId);
    }


    public Answer getAnswerForUUID(UUID iId) {
        return fAnswers.stream().filter( answer -> answer.getId().equals(iId)).findFirst().get();
    }

    // ------------------------------------------------------------------
    // Jsonable Implementation
    // ------------------------------------------------------------------
    public JsonObject asJsonObject()
    {
        JsonObject vResult = new JsonObject();
        vResult.put(KEY_NAME, fName);
        vResult.put(KEY_ANSWERS, fAnswers);
        vResult.put(KEY_ID, fId.toString());
        return vResult;
    }
    @Override
    public String toJson() {
        final StringWriter writable = new StringWriter();
        try{
            this.toJson(writable);
        }catch(final IOException caught)
        {
            caught.printStackTrace();
        }
        return writable.toString();
    }

    @Override
    public void toJson(Writer writable) throws IOException {
        writable.write(new String(asJsonObject().toJson().getBytes(StandardCharsets.UTF_8), StandardCharsets.UTF_8));
    }
}
