package model.questionnaire;

import com.github.cliftonlabs.json_simple.JsonObject;
import com.github.cliftonlabs.json_simple.Jsonable;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.UUID;

import static api.JsonKeys.*;

public class Session implements Jsonable {

    private static final HashMap<UUID, Session> sSessions = new HashMap<>();
    private final UUID fId;
    private final SessionAnswers fAnswers;

    public Session(){
        fId = UUID.randomUUID();
        fAnswers = new SessionAnswers();
        sSessions.put(fId, this);
    }


    public SessionAnswers getSessionAnswers(){ return fAnswers; }

    public static Session getSessionForUUID(UUID iId){
        return sSessions.get(iId);
    }


    // ------------------------------------------------------------------
    // Jsonable Implementation
    // ------------------------------------------------------------------
    public JsonObject asJsonObject() {
        JsonObject vResult = new JsonObject();
        vResult.put(KEY_ID, fId.toString());
        vResult.put(KEY_RESULTS, fAnswers.asJsonObject());
        return vResult;
    }


    @Override
    public String toJson() {
        final StringWriter writable = new StringWriter();
        try{
            this.toJson(writable);
        }catch(final IOException caught)
        {
            caught.printStackTrace();
        }
        return writable.toString();
    }


    @Override
    public void toJson(Writer writable) throws IOException {
        writable.write(new String(asJsonObject().toJson().getBytes(StandardCharsets.UTF_8), StandardCharsets.UTF_8));
    }

}
