import React from 'react';
import { createPortal } from 'react-dom';
import url from '../server';
import {ResponsiveRadar} from "@nivo/radar"

function QuestionnaireResult(props){
    const [resultsFetched, onResultsFetched] = React.useState(null);
    let dominant_weight = 0;
    let dominant = null;
    let radar_traits = [];
    let radar_data = [];
    let scale_start = ""
    let scale_end = ""

    if(null === resultsFetched)
    {
        fetch(url+"/session/"+props.sessionId) 
        .then(response => response.json())
        .then(result => {
            onResultsFetched(result.results);
        })
        .catch( e => console.error(e));
    }
    else
    {
        let total = 0;
        let max = 0;
        
        resultsFetched.traits.forEach(trait => {
            total += trait.weight;
            if(max < trait.weight)
            {
                max = trait.weight;
                dominant = trait;
            }
            radar_traits.push(trait.name); 
            radar_data.push({trait:trait.name, you:trait.weight});
        })
        dominant_weight = (dominant.weight/total) * 100;

        //normalize radar_data values
        radar_data.forEach(trait => {
            trait.you = ((trait.you/total) * 100).toFixed(1);
        })

        // two traits : display them on a scale
        if(radar_data.length == 2)
        {
             
            scale_start = dominant.name;
            
            scale_end = radar_data[0].trait == scale_start ? radar_data[1].trait : radar_data[0].trait;
        }
    }

        return(
        <React.Fragment>
        {null !== resultsFetched && radar_data.length > 2 &&
        <div 
            className="display_flex fill_width"
            style={{height:400}}
            >
        <ResponsiveRadar
            data={radar_data}
            keys={["you"]}
            margin={{ top: 70, right: 80, bottom: 40, left: 80 }}
            indexBy="trait"
            maxValue={100}
            format=">-.2%"
        />
        </div>
        }
        { radar_data.length == 2 &&
        <div className="gradient bordered" 
        style={{
            "--data-weight": dominant_weight+"%",
            "--data-grad-offset": dominant_weight+1+"%",
            }}>
            <div className="display_flex flex_horizontal space_between position_static fill_width">
            <div>{scale_start}</div>
            <div>{scale_end}</div>
            </div>
        </div>
        }
        {null != dominant &&
        <div>
            Approximately {dominant_weight.toFixed(1)}% : 🎉{dominant.description} 
        </div>
        }
        <div onClick={() => props.onStartQuestionnaire(false)} className="interactible">
            Restart
        </div>
        </React.Fragment>
    )
}

export default QuestionnaireResult;